.. image:: logo-300px.png
   :alt: uproot
   :target: https://github.com/scikit-hep/uproot
   :align: center

uproot
======

.. include:: ../../README.rst
  :start-after: inclusion-marker-1-do-not-remove
  :end-before:  inclusion-marker-3-do-not-remove

Tutorial
--------

See the `project homepage <https://github.com/scikit-hep/uproot>`__ for a `tutorial <https://github.com/scikit-hep/uproot#tutorial>`__.

Run `the tutorial <https://mybinder.org/v2/gh/scikit-hep/uproot/master?urlpath=lab/tree/binder%2Ftutorial.ipynb>`__ on Binder.

Reference documentation
-----------------------

.. toctree::
   :maxdepth: 3

   opening-files
   root-io
   ttree-handling
   interpretation
   caches
   parallel-io
